Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(366)

Unified Diff: src/gpu/GrGpu.h

Issue 579753003: Fix typo (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Missed an instance Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrContext.cpp ('k') | src/gpu/GrGpu.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrGpu.h
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h
index 1ae2f5856bd4cfe8a521f9744991f26170c5793a..48bb0d6400dd9a52c22ac14fc2302930a45b1027 100644
--- a/src/gpu/GrGpu.h
+++ b/src/gpu/GrGpu.h
@@ -62,8 +62,8 @@ public:
// Called by GrContext when the underlying backend context has been destroyed.
// GrGpu should use this to ensure that no backend API calls will be made from
// here onward, including in its destructor. Subclasses should call
- // INHERITED::contextAbandonded() if they override this.
- virtual void contextAbandonded();
+ // INHERITED::contextAbandoned() if they override this.
+ virtual void contextAbandoned();
/**
* The GrGpu object normally assumes that no outsider is setting state
« no previous file with comments | « src/gpu/GrContext.cpp ('k') | src/gpu/GrGpu.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698